ColumnDef class
Defines a single column's constraints.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Column name (header).
final
- nullable → bool
-
Whether null values are allowed.
final
- pattern → String?
-
Regex pattern the string value must match.
final
- required → bool
-
Whether this column must exist.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Type?
-
Expected type. Null means any type allowed.
final
- validator → bool Function(dynamic value)?
-
Custom validation function.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited