CsvColumn class
Describes a column in a CsvTable.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
Column index (0-based).
final
- inferredType → Type
-
Inferred type of this column based on non-null values.
no setter
- name → String
-
Column header name.
final
- nonNullCount → int
-
Count of non-null values.
no setter
- nullCount → int
-
Count of null values.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uniqueCount → int
-
Count of unique values (including null).
no setter
- values → List
-
All values in this column.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited