CsvValidationException class
Thrown when CSV data fails CsvSchema validation.
Contains the columnName, rowIndex, offending value, and the constraint that was violated.
- Inheritance
-
- Object
- CsvException
- CsvValidationException
Constructors
- CsvValidationException(String message, {required String columnName, required int rowIndex, required dynamic value, required String constraint})
-
const
Properties
- columnName → String
-
final
- constraint → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
- rowIndex → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited