FastEncoder class
High-performance batch CSV encoder using per-call StringBuffer.
Thread-safe: no global mutable state.
Constructors
- FastEncoder()
-
Create a batch encoder instance (stateless, reusable).
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
List< List> data, CsvConfig config) → String - Encode rows to CSV string with type-aware quoting.
-
encodeGeneric<
T> (List< List< data, CsvConfig config) → StringT> > - Encode numeric/bool data (no quoting needed).
-
encodeMap(
Map< String, dynamic> map, CsvConfig config) → String - Encode a Map as two-column CSV (key, value).
-
encodeStrings(
List< List< data, CsvConfig config) → StringString> > - Encode all-string data (skip type checks, always quote).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited